GradientButton class

Inheritance
Implementers

Constructors

GradientButton({required Widget child, required VoidCallback? callback, Key? key, Gradient gradient = Gradients.hotLinear, Color shadowColor = Colors.black45, ShapeBorder? shape, BorderRadius? shapeRadius, TextStyle? textStyle, double elevation = 5.0, bool isEnabled = true, Gradient? disabledGradient, double increaseHeightBy = 0.0, double increaseWidthBy = 0.0, BoxConstraints? constraints, Object? heroTag, String? tooltip, MaterialTapTargetSize? materialTapTargetSize})
const

Properties

callback VoidCallback?
finalinherited
child Widget
finalinherited
constraints BoxConstraints?
finalinherited
disabledGradient Gradient?
finalinherited
elevation double
finalinherited
gradient Gradient
finalinherited
hashCode int
The hash code for this object.
no setterinherited
heroTag Object?
finalinherited
increaseHeightBy double
finalinherited
increaseWidthBy double
finalinherited
isEnabled bool
finalinherited
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
materialTapTargetSize MaterialTapTargetSize?
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
shadowColor Color
finalinherited
shape ShapeBorder?
finalinherited
shapeRadius BorderRadius?
finalinherited
textStyle TextStyle?
finalinherited
tooltip String?
finalinherited

Methods

createElement() StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() → GradientButtonState
Creates the mutable state for this widget at a given location in the tree.
inherited
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited